// %flair:license{
// This file is part of the Flair framework distributed under the
// CECILL-C License, Version 1.0.
// %flair:license}
/*!
 * \file SimuPressureSensor.h
 * \brief Class for a simulation PressureSensor
 * \author Guillaume Sanahuja, Copyright Heudiasyc UMR UTC/CNRS 7253
 * \date 2018/05/24
 * \version 4.0
 */

#ifndef SIMUPRESSURESENSOR_H
#define SIMUPRESSURESENSOR_H

#include <PressureSensor.h>
#include <Thread.h>

namespace flair {
namespace core {
class SharedMem;
}
namespace gui {
class SpinBox;
}
}

namespace flair {
namespace sensor {
/*! \class SimuPressureSensor
*
* \brief Class for a simulation PressureSensor
*/
class SimuPressureSensor : public core::Thread, public PressureSensor {
public:
  /*!
  * \brief Constructor
  *
  * Construct a SimuPressureSensor.
	* It will be child of the FrameworkManager.
  *
  * \param name name
  * \param modelId Model id
  * \param deviceId PressureSensor id of the Model
  * \param priority priority of the Thread
  */
  SimuPressureSensor(std::string name,
         uint32_t modelId,uint32_t deviceId, uint8_t priority);

  /*!
  * \brief Destructor
  *
  */
  ~SimuPressureSensor();

protected:
  /*!
  * \brief SharedMem to access datas
  *
  */
  core::SharedMem *shmem;

private:
  /*!
  * \brief Update using provided datas
  *
  * Reimplemented from IODevice.
  *
  * \param data data from the parent to process
  */
  void UpdateFrom(const core::io_data *data){};

  /*!
  * \brief Run function
  *
  * Reimplemented from Thread.
  *
  */
  void Run(void);
  
  std::string ShMemName(uint32_t modelId,uint32_t deviceId);
  gui::SpinBox *data_rate;
};
} // end namespace sensor
} // end namespace flair
#endif // SIMUPRESSURESENSOR_H
